@@ -1,9 +1,10 @@
 /*
- * Copyright 2001-2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -63,7 +64,13 @@ public abstract class MappedPropertyRule extends RuleSupport {
                 // TODO: replace this call to introspector to an object call
                 // which finds all property descriptors for a class
                 // this allows extra property descriptors to be added 
-                BeanInfo beanInfo = Introspector.getBeanInfo( beanClass );
+                BeanInfo beanInfo;
+                if( getXMLIntrospector().getConfiguration().ignoreAllBeanInfo() ) {
+                    beanInfo = Introspector.getBeanInfo( beanClass, Introspector.IGNORE_ALL_BEANINFO );
+                }
+                else {
+                    beanInfo = Introspector.getBeanInfo( beanClass );
+                }
                 PropertyDescriptor[] descriptors = 
                     beanInfo.getPropertyDescriptors();
                 if ( descriptors != null ) {
