@@ -1,9 +1,10 @@
 /*
- * Copyright 2001-2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -330,7 +331,7 @@ public class BeanRuleSet implements RuleSet {
     /**
      * Specialization of <code>ReadContext</code> when reading from <code>Digester</code>.
      * @author <a href='http://jakarta.apache.org/'>Jakarta Commons Team</a>
-     * @version $Revision: 190509 $
+     * @version $Revision: 438373 $
      */
     private static class DigesterReadContext extends ReadContext {
 
@@ -401,7 +402,10 @@ public class BeanRuleSet implements RuleSet {
          */
         public Object popBean() {
             Object bean = super.popBean();
-            Object top = digester.pop();
+            // don't pop the last from the stack
+            if (digester.getCount() > 0) {
+                digester.pop();
+            }
             return bean;
         }
     }
